@@ -1,4 +1,4 @@
-from wcd_geo_db.modules.client import Client
+from px_client_builder import Client
 
 from .modules.addresses import AddressesClient
 from .modules.bank import BankClient
@@ -15,3 +15,8 @@ class GeoClient(Client):
     bank: BankClient = BankClient.as_property()
     names: NamesClient = NamesClient.as_property()
     addresses: AddressesClient = AddressesClient.as_property()
+
+    def __init__(self, *_, settings: Settings, **kw):
+        self.settings = settings
+
+        super().__init__(**kw)
