@@ -2,6 +2,7 @@ from typing import Any, List, Optional, Sequence, TypeVar
 from django.db import models
 from django.db.models.functions import Cast
 from django.contrib.postgres.search import TrigramSimilarity
+from django.db.models.functions import Greatest
 
 from wcd_geo_db.const import DivisionLevel
 from wcd_geo_db.modules.code_seeker.query import CodeSeekerQuerySet
@@ -56,13 +57,25 @@ class DivisionsQuerySet(
         if not q or len(q) < self.SEARCH_QUERY_MIN_LENGTH:
             return self
 
-        name_similarity = TrigramSimilarity(
-            'name', Cast(models.Value(q), output_field=models.TextField()),
-            function='strict_word_similarity'
+        name_similarity = Greatest(
+            TrigramSimilarity(
+                'name', Cast(models.Value(q), output_field=models.TextField()),
+                function='strict_word_similarity'
+            ),
+            TrigramSimilarity(
+                'translations__name', Cast(models.Value(q), output_field=models.TextField()),
+                function='strict_word_similarity'
+            ),
         )
-        synonyms_similarity = TrigramSimilarity(
-            'synonyms', Cast(models.Value(q), output_field=models.TextField()),
-            function='strict_word_similarity'
+        synonyms_similarity = Greatest(
+            TrigramSimilarity(
+                'synonyms', Cast(models.Value(q), output_field=models.TextField()),
+                function='strict_word_similarity'
+            ),
+            TrigramSimilarity(
+                'translations__synonyms', Cast(models.Value(q), output_field=models.TextField()),
+                function='strict_word_similarity'
+            ),
         )
 
         queryset = (
