@@ -1,5 +1,6 @@
 from typing import Any, Optional, Sequence, Tuple
-from wcd_geo_db.modules.client import DBClientMixin, NestedClient
+from wcd_geo_db.modules.client import DBClientMixin
+from px_client_builder import NestedClient
 from wcd_geo_db.const import DivisionLevel
 
 from ..dtos import DivisionNameDTO, DivisionNameTranslationDTO
