@@ -1,4 +1,4 @@
-from typing import Any, Dict, Sequence, Tuple
+from typing import Any, Dict, Optional, Sequence, Tuple
 from django.db import models
 from wcd_geo_db.modules.code_seeker import CodeSeekerRegistry
 
@@ -15,6 +15,7 @@ class CodeMapper:
         self.items = items
         self.registry = registry
         self.mapping = {}
+        self.name_groups = {}
 
         self.prepare_mapping()
 
@@ -27,6 +28,9 @@ class CodeMapper:
                     mapping[code] = mapping.get(code) or []
                     mapping[code].append((value, item))
 
+            self.name_groups[item.name] = self.name_groups.get(item.name) or []
+            self.name_groups[item.name].append(item)
+
     def get_by_codes(self, codes: Sequence):
         r = self.registry
 
@@ -36,9 +40,18 @@ class CodeMapper:
             for stored_value, item in (self.mapping.get(code) or [])
             if (
                 # code in self.registry and
-                self.registry[code].eq(value, stored_value)
+                r[code].eq(
+                    r[code].to_representation(value),
+                    r[code].to_representation(stored_value)
+                )
             )
         )
 
-    def get_one(self, codes: Sequence) -> models.Model:
+    def get_one(self, codes: Sequence) -> Optional[models.Model]:
         return next(self.get_by_codes(codes), None)
+
+    def get_one_by_name(self, name: str) -> Optional[models.Model]:
+        if name in self.name_groups and len(self.name_groups[name]) == 1:
+            return self.name_groups[name][0]
+
+        return None
